from bs4 import BeautifulSoup as bs


class Pretiffy:
    def __init__(self, text="", filePath=""):
        self.filePath = filePath
        self.text = text
        if self.filePath != "":
            self.fromFile()

    def save(self, out="out.html"):
        with open(out, "w", encoding="utf-8") as fi:
            fi.write(self.pretiffy_string())

    def fromFile(self):
        if self.filePath != "":
            with open(self.filePath, "r", encoding="utf-8") as f:
                self.text = f.read()

    def pretiffy_string(self):
        soup = bs(self.text, "html.parser")
        return soup.prettify()

    def __str__(self) -> str:
        return self.pretiffy_string()

    def __repr__(self) -> str:
        return self.pretiffy_string()



replace = {
    "classs": "class",
    "forr": "for",
    "accessskey": "accesskey",
    "aria_lable": "aria-label",
    "comment": "!--",
    "aria_describedby": "aria-describedby",
    "iss": "is",
    "doctype": "!DOCTYPE HTML",
    "typee": "type",
}



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()


VERSION = '0.1.8'

PACKAGE_NAME = "inui"
DESCRIPTION = ''
LONG_DESCRIPTION = 'Powerful and Highly Customizable Python Library for UI'
AUTHOR_NAME = "Mohammadreza Amani"
AUTHOR_EMAIL = "more.amani@yahoo.com"
PROJECT_URL = "https://github.com/MohammadrezaAmani/INUI/"
REQUIRED_PACKAGES = ['beautifulsoup4']
PROJECT_KEYWORDS = ['ui', 'python', 'html', 'framework','frontend','bootstrap']

CLASSIFIERS = [
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows"]

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    author=AUTHOR_NAME,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    url = PROJECT_URL,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=REQUIRED_PACKAGES,
    keywords=PROJECT_KEYWORDS,
    classifiers=CLASSIFIERS
)